@@ -29,7 +29,6 @@
 #include "xkbpath.h"
 #include <X11/keysym.h>
 #include <X11/extensions/XKBgeom.h>
-#include <X11/Xalloca.h>
 #include <limits.h>
 #include <stdlib.h>
 
@@ -556,10 +555,8 @@ OverlayKeyCreate(char *under, char *over)
         key->common.stmtType = StmtOverlayKeyDef;
         strncpy(key->over, over, XkbKeyNameLength);
         strncpy(key->under, under, XkbKeyNameLength);
-        if (over)
-            uFree(over);
-        if (under)
-            uFree(under);
+        uFree(over);
+        uFree(under);
     }
     return key;
 }
@@ -748,12 +745,12 @@ IncludeCreate(char *str, unsigned merge)
 void
 PrintStmtAddrs(ParseCommon * stmt)
 {
-    fprintf(stderr, "0x%x", stmt);
+    fprintf(stderr, "%p", stmt);
     if (stmt)
     {
         do
         {
-            fprintf(stderr, "->0x%x", stmt->next);
+            fprintf(stderr, "->%p", stmt->next);
             stmt = stmt->next;
         }
         while (stmt);
@@ -797,7 +794,7 @@ XKBParseFile(FILE * file, XkbFile ** pRtrn)
 {
     if (file)
     {
-        yyin = file;
+        scan_set_file(file);
         rtrnValue = NULL;
         if (yyparse() == 0)
         {
