@@ -40,10 +40,6 @@
 #include "misc.h"
 #include "alias.h"
 
-extern Atom tok_ONE_LEVEL;
-extern Atom tok_TWO_LEVEL;
-extern Atom tok_KEYPAD;
-
 /***====================================================================***/
 
 #define	RepeatYes	1
@@ -932,7 +928,7 @@ GetGroupIndex(KeyInfo * key,
 static Bool
 AddSymbolsToKey(KeyInfo * key,
                 XkbDescPtr xkb,
-                char *field,
+                const char *field,
                 ExprDef * arrayNdx, ExprDef * value, SymbolsInfo * info)
 {
     unsigned ndx, nSyms;
@@ -986,7 +982,7 @@ AddSymbolsToKey(KeyInfo * key,
 static Bool
 AddActionsToKey(KeyInfo * key,
                 XkbDescPtr xkb,
-                char *field,
+                const char *field,
                 ExprDef * arrayNdx, ExprDef * value, SymbolsInfo * info)
 {
     register int i;
@@ -1122,7 +1118,7 @@ static LookupEntry rgEntries[] = {
 static Bool
 SetSymbolsField(KeyInfo * key,
                 XkbDescPtr xkb,
-                char *field,
+                const char *field,
                 ExprDef * arrayNdx, ExprDef * value, SymbolsInfo * info)
 {
     Bool ok = True;
@@ -1239,7 +1235,7 @@ SetSymbolsField(KeyInfo * key,
              uStrCasePrefix("permanentoverlay", field))
     {
         Bool permanent = False;
-        char *which;
+        const char *which;
         int overlayNdx;
         if (uStrCasePrefix("permanent", field))
         {
@@ -1714,7 +1710,7 @@ FindKeyForSymbol(XkbDescPtr xkb, KeySym sym, unsigned int *kc_rtrn)
             if (j < (int) XkbKeyNumSyms(xkb, i))
             {
                 gotOne = True;
-                if ((XkbKeySym(xkb, i, j) == sym))
+                if (XkbKeySym(xkb, i, j) == sym)
                 {
                     *kc_rtrn = i;
                     return True;
