@@ -47,9 +47,6 @@
 #include "tokens.h"
 #include <X11/extensions/XKBgeom.h>
 
-#ifdef __UNIXOS2__
-#define chdir _chdir2
-#endif
 
 #ifdef WIN32
 #define S_IRGRP 0
@@ -119,6 +116,7 @@ Usage(int argc, char *argv[])
         M1("Usage: %s [options] file[(map)] ...\n", argv[0]);
     M("Legal options:\n");
     M("-?,-help             Print this message\n");
+    M("-version             Print the version number\n");
     if (!xkblist)
     {
         M("-a                   Show all actions\n");
@@ -252,7 +250,11 @@ parseArgs(int argc, char *argv[])
             Usage(argc, argv);
             exit(0);
         }
-        else if ((strcmp(argv[i], "-a") == 0) && (!xkblist))
+        else if (strcmp(argv[i], "-version") == 0)
+        {
+            printf("xkbcomp %s\n", PACKAGE_VERSION);
+            exit(0);
+        } else if ((strcmp(argv[i], "-a") == 0) && (!xkblist))
         {
             showImplicit = True;
         }
@@ -574,17 +576,37 @@ parseArgs(int argc, char *argv[])
         }
         else if (strncmp(argv[i], "-w", 2) == 0)
         {
-            if ((i >= (argc - 1)) || (!isdigit(argv[i + 1][0])))
+            unsigned long utmp;
+            char *tmp2;
+            /* If text is just after "-w" in the same word, then it must
+             * be a number and it is the warning level. Otherwise, if the
+             * next argument is a number, then it is the warning level,
+             * else the warning level is assumed to be 0.
+             */
+            if (argv[i][2] == '\0')
             {
                 warningLevel = 0;
-                if (isdigit(argv[i][1]))
-                    if (sscanf(&argv[i][1], "%i", &itmp) == 1)
-                        warningLevel = itmp;
+                if (i < argc - 1)
+                {
+                    utmp = strtoul(argv[i+1], &tmp2, 10);
+                    if (argv[i+1][0] != '\0' && *tmp2 == '\0')
+                    {
+                        warningLevel = utmp > 10 ? 10 : utmp;
+                        i++;
+                    }
+                }
             }
             else
             {
-                if (sscanf(argv[++i], "%i", &itmp) == 1)
-                    warningLevel = itmp;
+                utmp = strtoul(&argv[i][2], &tmp2, 10);
+                if (*tmp2 == '\0')
+                    warningLevel = utmp > 10 ? 10 : utmp;
+                else
+                {
+                    ERROR1("Unknown flag \"%s\" on command line\n", argv[i]);
+                    Usage(argc, argv);
+                    return False;
+                }
             }
         }
         else if ((strcmp(argv[i], "-xkb") == 0) && (!xkblist))
@@ -648,25 +670,25 @@ parseArgs(int argc, char *argv[])
         len = strlen(inputFile);
         if (inputFile[len - 1] == ')')
         {
-            char *tmp;
-            if ((tmp = strchr(inputFile, '(')) != NULL)
+            char *tmpstr;
+            if ((tmpstr = strchr(inputFile, '(')) != NULL)
             {
-                *tmp = '\0';
+                *tmpstr = '\0';
                 inputFile[len - 1] = '\0';
-                tmp++;
-                if (*tmp == '\0')
+                tmpstr++;
+                if (*tmpstr == '\0')
                 {
                     WARN("Empty map in filename\n");
                     ACTION("Ignored\n");
                 }
                 else if (inputMap == NULL)
                 {
-                    inputMap = uStringDup(tmp);
+                    inputMap = uStringDup(tmpstr);
                 }
                 else
                 {
                     WARN("Map specified in filename and with -m flag\n");
-                    ACTION1("map from name (\"%s\") ignored\n", tmp);
+                    ACTION1("map from name (\"%s\") ignored\n", tmpstr);
                 }
             }
             else
@@ -743,7 +765,7 @@ parseArgs(int argc, char *argv[])
             ACTION("Exiting\n");
             exit(1);
         }
-        sprintf(outputFile, "stdin.%s", fileTypeExt[outputFormat]);
+        snprintf(outputFile, len, "stdin.%s", fileTypeExt[outputFormat]);
     }
     else if ((outputFile == NULL) && (inputFile != NULL))
     {
@@ -771,7 +793,7 @@ parseArgs(int argc, char *argv[])
         }
         ext = strrchr(base, '.');
         if (ext == NULL)
-            sprintf(outputFile, "%s.%s", base, fileTypeExt[outputFormat]);
+            snprintf(outputFile, len, "%s.%s", base, fileTypeExt[outputFormat]);
         else
         {
             strcpy(outputFile, base);
@@ -878,8 +900,7 @@ main(int argc, char *argv[])
     XkbFileInfo result;
     Status status;
 
-    yyin = stdin;
-    uSetEntryFile(NullString);
+    scan_set_file(stdin);
     uSetDebugFile(NullString);
     uSetErrorFile(NullString);
 
@@ -1037,6 +1058,7 @@ main(int argc, char *argv[])
                 ok = False;
                 break;
             }
+            result.xkb->device_spec = device_id;
         }
         else if (inputFormat == INPUT_XKM) /* parse xkm file */
         {
@@ -1053,6 +1075,7 @@ main(int argc, char *argv[])
                 ERROR1("Cannot read XKM file \"%s\"\n", inputFile);
                 ok = False;
             }
+            result.xkb->device_spec = device_id;
         }
         else
         {
